==> tasks-v1.8.8.zip: tasks/messages/fa-IR/base.php <==
<?php

return [
    '<strong>Create</strong> task list' => '<strong>ساخت</strong> فهرست کارها',
    '<strong>Edit</strong> task' => '<strong>ويرايش وظيفه</strong>',
    '<strong>Edit</strong> task list' => '<strong>ویرایش</strong> فهرست کارها',
    '<strong>Task</strong> Overview' => 'دیدکلی <strong>کار</strong>',
    'Accept Task' => 'پذیرش کار',
    'Add task' => 'افزودن کار',
    'All Day' => 'تمام روز',
    'Assign users' => 'اختصاص كاربر',
    'Assignments:' => 'برگماشته‌ها:',
    'Begin Task' => 'آغاز کار',
    'Close' => 'بستن',
    'Color' => 'رنگ',
    'Create tasks' => 'ساخت کارها',
    'Created by me' => 'ایجادشده توسط من',
    'Date' => 'تاريخ',
    'Delete' => 'حذف',
    'Delete list' => 'حذف فهرست',
    'Description' => 'توضیحات',
    'Do you really want to delete this task?' => 'وظيفه حذف شود؟',
    'Edit' => 'ویرایش',
    'Edit list' => 'ویرایش فهرست',
    'End Date' => 'تاریخ پایان',
    'End Time' => 'پایان زمان',
    'End time must be after start time!' => 'تاریخ پایان باید پس از تاریخ آغاز باشد!',
    'Filter' => 'پالایه',
    'Finish Task' => 'پایان کار',
    'General' => 'کلی',
    'General Settings' => 'تنظیمات کلی',
    'No pending tasks found' => 'هیچ کار در انتظاری یافت نشد',
    'Other Tasks' => 'کارهای دیگر',
    'Overview' => 'بررسی اجمالی',
    'Ready For Review' => 'آماده برای بازبینی',
    'Reset Task' => 'بازنشانی کار',
    'Scheduling' => 'زمان‌بندی',
    'Sort Order' => 'ترتیب مرتب‌سازی',
    'Sort order' => 'ترتیب مرتب‌سازی',
    'Spaces' => 'انجمن‌ها',
    'Start Date' => 'تاریخ شروع',
    'Start Time' => 'آغاز زمان',
    'Status' => 'وضعیت',
    'Task' => 'کار',
    'Tasks' => 'کارها',
    'Tasks: Reminder' => 'کارها: یادآوری',
    'Time Zone' => 'منطقه زمانی',
    'Title' => 'عنوان',
    'Unsorted' => 'نامرتب',
    'View Online' => 'مشاهده آنلاین',
    'You have insufficient permissions to perform that operation!' => 'شما  مجاز به انجام عملیات نیستید!',
    'view all' => 'نمایش همه',
    '{userName} completed task {task}.' => '{userName} کار {task} را کامل کرد.',
    '{userName} finished task {task}.' => '{userName} {task} را به پایان رساند.',
    '{userName} reset task {task}.' => '{userName} کار {task} را بازنشانی کرد.',
    '{userName} reviewed task {task}.' => '{userName} کار {task} را بازبینی کرد.',
    '{userName} works on task {task}.' => '{userName} بر روی {task} کار می‌کند.',
    '1 Day before' => '',
    '1 Month before' => '',
    '1 Week before' => '',
    '2 Days before' => '',
    '2 Weeks before' => '',
    '3 Weeks before' => '',
    '<strong>Assigned users</strong> are allowed to process this task.' => '',
    '<strong>Confirm</strong> task deletion' => '',
    '<strong>New</strong> Task' => '',
    '<strong>Tasks</strong>' => '',
    '<strong>Tasks</strong> module configuration' => '',
    '<strong>Your</strong> tasks' => '',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => '',
    'Add Deadline to space calendar' => '',
    'Add checkpoint...' => '',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => '',
    'Add entry to main navigation' => '',
    'Add reminder' => '',
    'Add responsible users' => '',
    'Add schedule to the space calendar' => '',
    'Add to space calendar' => '',
    'Additional options' => '',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => '',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => '',
    'Allows the user to process unassigned tasks' => '',
    'Already requested' => '',
    'Any user with a "Process unassigned tasks" permission can work on this task' => '',
    'Anyone can work on this task!' => '',
    'Assign myself' => '',
    'Assigned' => '',
    'Assigned users' => '',
    'Assignment' => '',
    'At least 1 Hour before' => '',
    'At least 2 Hours before' => '',
    'Attachments' => '',
    'Checklist Items' => '',
    'Checklist:' => '',
    'Checkpoints' => '',
    'Choose if you want the module to appear in the main navigation.' => '',
    'Completed' => '',
    'Completed lists' => '',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '',
    'Continue Review' => '',
    'Deadline at' => '',
    'Deadline: ' => '',
    'Do not remind' => '',
    'Don\'t add to calendar' => '',
    'Drag entry' => '',
    'Edit item (empty field will be removed)...' => '',
    'End' => '',
    'End date' => '',
    'Extend deadline request' => '',
    'Filter by status' => '',
    'Filter by title' => '',
    'Filter tasks' => '',
    'Hide this list once all tasks are completed' => '',
    'I\'m assigned' => '',
    'I\'m responsible' => '',
    'If empty any user can complete the task.' => '',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => '',
    'In Progress' => '',
    'In Review' => '',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => '',
    'Invalid task list selection.' => '',
    'Let Task Review' => '',
    'Main Navigation' => '',
    'Manage tasks' => '',
    'Maximum number of entries in widget' => '',
    'Module Widget' => '',
    'New list or search' => '',
    'No Scheduling set for this Task' => '',
    'No results found for the given filter.' => '',
    'Open Task' => '',
    'Overdue' => '',
    'Parent Task' => '',
    'Pending' => '',
    'Pending Review' => '',
    'Process unassigned tasks' => '',
    'Receive Notifications for Task Reminder.' => '',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => '',
    'Reject Task' => '',
    'Remind Mode' => '',
    'Reminder' => '',
    'Reminder sent' => '',
    'Reminders' => '',
    'Request extension' => '',
    'Request sent' => '',
    'Responsible' => '',
    'Responsible users' => '',
    'Review by responsible user required' => '',
    'Show widget in Spaces' => '',
    'Show widget on Dashboard' => '',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => '',
    'Start' => '',
    'Start date' => '',
    'Starting at' => '',
    'Task List' => '',
    'Task Users have been notified' => '',
    'Task content ID' => '',
    'Task {task} in space {spaceName} ends at {dateTime}.' => '',
    'Task {task} in space {spaceName} starts at {dateTime}.' => '',
    'This task can only be processed by assigned and responsible users.' => '',
    'This task requires to be reviewed by a responsible' => '',
    'Title and Color' => '',
    'Title of your task list' => '',
    'Today' => '',
    'You are assigned!' => '',
    'You are responsible!' => '',
    'Your Reminder for task {task}' => '',
    'ending Review' => '',
    '{count,plural,=1{# day} other{# days}} remaining' => '',
    '{displayName} is assigned to this task' => '',
    '{displayName} is responsible for this task' => '',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '',
    '{userName} assigned you to task {task} in space {spaceName}.' => '',
    '{userName} completed Task {task} in space {spaceName}.' => '',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '',
    '{userName} has re-opened task {task} in space {spaceName}.' => '',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '',
    '{userName} started working on Task {task} in space {spaceName}.' => '',
];

==> tasks-v1.9.1.zip: tasks/messages/fa-IR/base.php <==
<?php

return [
    '<strong>Create</strong> task list' => '<strong>ساخت</strong> فهرست کارها',
    '<strong>Edit</strong> task' => '<strong>ويرايش وظيفه</strong>',
    '<strong>Edit</strong> task list' => '<strong>ویرایش</strong> فهرست کارها',
    '<strong>Task</strong> Overview' => 'دیدکلی <strong>کار</strong>',
    'Accept Task' => 'پذیرش کار',
    'Add task' => 'افزودن کار',
    'All Day' => 'تمام روز',
    'Assign users' => 'اختصاص كاربر',
    'Begin Task' => 'آغاز کار',
    'Close' => 'بستن',
    'Color' => 'رنگ',
    'Create tasks' => 'ساخت کارها',
    'Created by me' => 'ایجادشده توسط من',
    'Date' => 'تاريخ',
    'Delete' => 'حذف',
    'Delete list' => 'حذف فهرست',
    'Description' => 'توضیحات',
    'Do you really want to delete this task?' => 'وظيفه حذف شود؟',
    'Edit' => 'ویرایش',
    'Edit list' => 'ویرایش فهرست',
    'End Date' => 'تاریخ پایان',
    'End Time' => 'پایان زمان',
    'End time must be after start time!' => 'تاریخ پایان باید پس از تاریخ آغاز باشد!',
    'Filter' => 'پالایه',
    'Finish Task' => 'پایان کار',
    'General' => 'کلی',
    'General Settings' => 'تنظیمات کلی',
    'No pending tasks found' => 'هیچ کار در انتظاری یافت نشد',
    'Other Tasks' => 'کارهای دیگر',
    'Overview' => 'بررسی اجمالی',
    'Ready For Review' => 'آماده برای بازبینی',
    'Reset Task' => 'بازنشانی کار',
    'Scheduling' => 'زمان‌بندی',
    'Sort Order' => 'ترتیب مرتب‌سازی',
    'Sort order' => 'ترتیب مرتب‌سازی',
    'Spaces' => 'انجمن‌ها',
    'Start Date' => 'تاریخ شروع',
    'Start Time' => 'آغاز زمان',
    'Status' => 'وضعیت',
    'Task' => 'کار',
    'Tasks' => 'کارها',
    'Tasks: Reminder' => 'کارها: یادآوری',
    'Time Zone' => 'منطقه زمانی',
    'Title' => 'عنوان',
    'Unsorted' => 'نامرتب',
    'View Online' => 'مشاهده آنلاین',
    'You have insufficient permissions to perform that operation!' => 'شما  مجاز به انجام عملیات نیستید!',
    'view all' => 'نمایش همه',
    '{userName} completed task {task}.' => '{userName} کار {task} را کامل کرد.',
    '{userName} finished task {task}.' => '{userName} {task} را به پایان رساند.',
    '{userName} reset task {task}.' => '{userName} کار {task} را بازنشانی کرد.',
    '{userName} reviewed task {task}.' => '{userName} کار {task} را بازبینی کرد.',
    '{userName} works on task {task}.' => '{userName} بر روی {task} کار می‌کند.',
    '1 Day before' => '',
    '1 Month before' => '',
    '1 Week before' => '',
    '2 Days before' => '',
    '2 Weeks before' => '',
    '3 Weeks before' => '',
    '<strong>Assigned users</strong> are allowed to process this task.' => '',
    '<strong>Confirm</strong> task deletion' => '',
    '<strong>New</strong> Task' => '',
    '<strong>Tasks</strong>' => '',
    '<strong>Tasks</strong> module configuration' => '',
    '<strong>Your</strong> tasks' => '',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => '',
    'Add Deadline to space calendar' => '',
    'Add checkpoint...' => '',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => '',
    'Add entry to main navigation' => '',
    'Add reminder' => '',
    'Add responsible users' => '',
    'Add schedule to the space calendar' => '',
    'Add to space calendar' => '',
    'Additional options' => '',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => '',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => '',
    'Allows the user to process unassigned tasks' => '',
    'Already requested' => '',
    'Assign myself' => '',
    'Assigned users' => '',
    'Assignment' => '',
    'Assignments' => '',
    'At least 1 Hour before' => '',
    'At least 2 Hours before' => '',
    'Attachments' => '',
    'Checklist Items' => '',
    'Checklist:' => '',
    'Checkpoints' => '',
    'Choose if you want the module to appear in the main navigation.' => '',
    'Completed' => '',
    'Completed lists' => '',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '',
    'Continue Review' => '',
    'Deadline' => '',
    'Deadline: ' => '',
    'Do not remind' => '',
    'Don\'t add to calendar' => '',
    'Edit item (empty field will be removed)...' => '',
    'End' => '',
    'End date' => '',
    'Extend deadline request' => '',
    'Filter by status' => '',
    'Filter by title' => '',
    'Filter tasks' => '',
    'Hide this list once all tasks are completed' => '',
    'I\'m assigned' => '',
    'I\'m responsible' => '',
    'ID' => '',
    'If empty any user can complete the task.' => '',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => '',
    'In Progress' => '',
    'In Review' => '',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => '',
    'Invalid task list selection.' => '',
    'Let Task Review' => '',
    'Main Navigation' => '',
    'Manage tasks' => '',
    'Maximum number of entries in widget' => '',
    'Module Widget' => '',
    'New list or search' => '',
    'No Scheduling set for this Task' => '',
    'No results found for the given filter.' => '',
    'Open Task' => '',
    'Overdue' => '',
    'Parent Task' => '',
    'Pending' => '',
    'Pending Review' => '',
    'Process unassigned tasks' => '',
    'Receive Notifications for Task Reminder.' => '',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => '',
    'Reject Task' => '',
    'Remind Mode' => '',
    'Reminder' => '',
    'Reminder sent' => '',
    'Reminders' => '',
    'Request Review' => '',
    'Request extension' => '',
    'Request sent' => '',
    'Responsible' => '',
    'Responsible users' => '',
    'Review by responsible user required' => '',
    'Show widget in Spaces' => '',
    'Show widget on Dashboard' => '',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => '',
    'Start' => '',
    'Start date' => '',
    'Starting at' => '',
    'Task List' => '',
    'Task Users have been notified' => '',
    'Task content ID' => '',
    'Task {task} in space {spaceName} ends at {dateTime}.' => '',
    'Task {task} in space {spaceName} starts at {dateTime}.' => '',
    'This task requires to be reviewed by a responsible' => '',
    'Title and Color' => '',
    'Title of your task list' => '',
    'Today' => '',
    'Your Reminder for task {task}' => '',
    '{count,plural,=1{# day} other{# days}} remaining' => '',
    '{displayName} is assigned to this task' => '',
    '{displayName} is responsible for this task' => '',
    '{displayName} is task creator' => '',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '',
    '{userName} assigned you to task {task} in space {spaceName}.' => '',
    '{userName} completed Task {task} in space {spaceName}.' => '',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '',
    '{userName} has re-opened task {task} in space {spaceName}.' => '',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '',
    '{userName} started working on Task {task} in space {spaceName}.' => '',
];
